Functions
==========

You can find here the API documentation of NeuroKit, with a description of all the functions and examples on how to use them.

.. toctree::
   :maxdepth: 2
   :caption: Modules
   :titlesonly:

   Bio <bio>
   ecg
   ppg
   hrv
   rsp
   eda
   emg
   eog
   eeg
   video
   Microstates <microstates>
   Signal <signal>
   events
   epochs
   data
   Complexity <complexity>
   markov
   stats
   misc
   Benchmarking <benchmark>



